## Description of the file structure of the database  “Chronicles of Nature Calendar: A long-term and large-scale multitaxon database on phenology“

The database consists of six data files, each formatted as a .csv (comma-separated values) file. 

The main data are provided in the phenology table, where each row describes at which day of the year (Field Day.of.year) a particular phenological event (Field Event.type) was observed for a particular species (fields Taxon and Taxon.identifier) in a particular year (field Year) and particular study site (field Study.site) that was part of a particular project (Field Project). Each row contains also a quality indicator (field Quality), which his set to “OK” if the data point has passed all the technical validation steps described in the data paper. Cases that were highlighted by the technical validation steps and thus that may be unreliable (and that we recommend to remove from analyses) are indicated as “Event.Type outlier”, “Locality-Taxonomic.Name-Event.Type bimodal”, “Locality-Taxonomic.Name-Event.Type outlier”, “Taxonomic.Name-Event.Type bimodal”, and “Taxonomic.Name-Event.Type outlier”. The criteria for how these were defined are described in the data paper.

The remaining data tables contain additional information that can be linked to the phenology table. First, the taxonomy table describes the taxonomical information (e.g. species for which the observation is made), and is linked to the phenology table through the shared fields Taxon and Taxon.identifier. Second, the phenological events table gives further information for each phenological event, and is linked to the phenology table through the shared field Event.type. Third, for data points that refer to climatic rather than to phenological events, the climatic events table gives further information for each  climatic event, and is linked to the phenology table through the shared field Event.type. Fourth, the study sites table gives the longitude and latitude of each study site, and is linked to the phenology table through the shared field Study.site. Fifth, the information sources table gives the reference to the original data, and is linked to the phenology table through the shared field Project.

Below we describe the fields present in each data file and their explanations. In all data files, missing information is coded as NA.

### The phenology table (Phenology.csv):

- Project: The name of the project in which the data were collected
- Dataset: The name of the dataset to which the data belongs to 
- Study.site: The name of the study site in which the data were collected
- Taxon.identifier: The unique identifier of the taxon (“Climate” for climatic events)
- Taxon: The scientific name of taxon (climatic group for climatic events)
- Event.type: The type of the event
- Year: The year
- Day.of.year: The date of the observation as the number of days since January 1st in the focal year 
- Quality: An indicator variable of any quality issues were identified with the data

### The taxonomy table (Taxonomy.csv):

- Taxon.identifier: The unique identifier of the taxon
- Taxon: The scientific name of the taxon
- Taxonomic.level: The highest taxonomical level to which the taxon is described
- Kingdom: Kingdom
- Phylum: Phylum
- Class: Class
- Order: Order
- Family: Family
- Genus: Genus
- Species: Species
- GBIF.key: The GBIF key for the taxon
- GBIF.status: Whether the GBIF status of the taxon is accepted

### The phenological events table (Phenological events.csv):

- Kingdom: The kingdom for which the phenological event is relevant
- Event.type: The name of the phenological event
- Description: The description of the phenological event
- BBCH: BBCH-scale used to identify the phenological development stages of plants

### The climatic events table (Climatic events.csv):

- Group: The type of the climatic event (e.g. related to temperature, snow or ice)
- Event.type: The name of the climatic event
- Description: The description of the climatic event

### The study sites table (Study sites.csv):

- Study.site: The name of the study site
- Latitude: Latitude (typically of center of protected area)
- Longitude: Longitude (typically of center of protected area)

### The information sources table (Information sources.csv):

- Project: The name of the project
- Source: The type of information sources (mostly Chronicles of Nature Books of the participating organizations)
- Reference: The references used to extract the phenology data
